@@ -1,18 +1,25 @@
-##########################################################################################################
-# Miscellaneous functions for "linkcomm".                                                                #
-#                                                                                                        #
-# Author: Alex T. Kalinka (alex.t.kalinka@gmail.com)                                                     #
-#                                                                                                        #
-# See: Ahn et al. (2010). Link communities reveal multiscale complexity in networks. Nature 466:761-765. #
-#                                                                                                        #
-##########################################################################################################
+#####################################################################################################
+# Miscellaneous functions for linkcomm.						                    #
+#                                                                                                   #
+# Author: Alex T. Kalinka (alex.t.kalinka@gmail.com)                                                #
+#                                                                                                   #
+# See: 												    #
+#												    #
+# Ahn et al. (2010). Link communities reveal multiscale complexity in networks. Nature 466:761-765. #
+#												    #
+# Kalinka & Tomancak (2011) linkcomm: an R package for  					    #
+#   the generation, visualization, and analysis of link 					    #
+#   communities in networks of arbitrary size and type. 					    #
+#   Bioinformatics 27:2011-2012.								    #
+#                                                                                                   #
+#####################################################################################################
 
 
 print.linkcomm <- function(x, ...)
 	# S3 method for generic function "print".
 	# x is a "linkcomm" object.
 	{
-	cat("   *** Summary ***\n   Number of nodes = ",x$numbers[2],"\n   Number of edges = ",x$numbers[1],"\n   Number of communities = ",x$numbers[3],"\n   Link partition density maximum height = ",x$pdmax,"\n   Number of nodes in largest cluster = ",x$clustsizes[1],"\n   Directed: ",x$directed,"\n   Hclust method: ",x$hclust$method,"\n")
+	cat("   *** Summary ***\n   Number of nodes = ",x$numbers[2],"\n   Number of edges = ",x$numbers[1],"\n   Number of communities = ",x$numbers[3],"\n   Maximum partition density = ",max(x$pdens[,2]),"\n   Number of nodes in largest cluster = ",x$clustsizes[1],"\n   Directed: ",x$directed,"\n   Hclust method: ",x$hclust$method,"\n")
 	}
 
 
@@ -325,14 +332,7 @@ getClusterRelatedness <- function(x, clusterids = 1:x$numbers[3], hcmethod = "wa
 
 	emptyvec <- rep(1,(length(clusterids)*(length(clusterids)-1))/2)
 
-	# Can we use carriage returns in our progress indicators?
-	if(.Platform$OS.type == "unix"){
-		carriageret <- TRUE
-	}else{
-		carriageret <- FALSE
-		}
-
-	dissvec <- .C("getJaccards", as.integer(nodes), as.integer(clusters), as.integer(clusterids), as.integer(numN), dissvec = as.double(emptyvec), as.logical(verbose), as.logical(carriageret))$dissvec
+	dissvec <- .C("getJaccards", as.integer(nodes), as.integer(clusters), as.integer(clusterids), as.integer(numN), dissvec = as.double(emptyvec), as.logical(verbose))$dissvec
 
 	if(cluster){
 		distmatrix <- matrix(1,length(clusterids),length(clusterids))
@@ -372,14 +372,7 @@ cutDendrogramAt <- function(x, lc = NULL, cutat = NULL, plot = TRUE, col = TRUE,
 	{
 	numM <- length(which(x$height <= cutat))
 
-	# Can we use carriage returns in our progress indicators?
-	if(.Platform$OS.type == "unix"){
-		carriageret <- TRUE
-	}else{
-		carriageret <- FALSE
-		}
-
-	csize <- .C("cutTreeAt", as.integer(x$merge[1:numM,1]), as.integer(x$merge[1:numM,2]), as.double(x$height[1:numM]), as.double(cutat), csize = integer(1), as.integer(numM), as.logical(carriageret))$csize
+	csize <- .C("cutTreeAt", as.integer(x$merge[1:numM,1]), as.integer(x$merge[1:numM,2]), as.double(x$height[1:numM]), as.double(cutat), csize = integer(1), as.integer(numM))$csize
 			
 	# Read in clusters from a file.
 	clus <- list()
@@ -430,14 +423,7 @@ newLinkCommsAt <- function(x, cutat = 0.5)
 	{
 	numM <- length(which(x$hclust$height <= cutat))
 
-	# Can we use carriage returns in our progress indicators?
-	if(.Platform$OS.type == "unix"){
-		carriageret <- TRUE
-	}else{
-		carriageret <- FALSE
-		}
-
-	csize <- .C("cutTreeAt", as.integer(x$hclust$merge[1:numM,1]), as.integer(x$hclust$merge[1:numM,2]), as.double(x$hclust$height[1:numM]), as.double(cutat), csize = integer(1), as.integer(numM), as.logical(carriageret))$csize
+	csize <- .C("cutTreeAt", as.integer(x$hclust$merge[1:numM,1]), as.integer(x$hclust$merge[1:numM,2]), as.double(x$hclust$height[1:numM]), as.double(cutat), csize = integer(1), as.integer(numM))$csize
 
 	if(csize == 0){
 		stop("\nThere are no clusters appearing at this height; maybe try a different height.\n")
